@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys, time, os
+import sys
+import time
+import os
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 from PyQt4.QtCore import Qt
@@ -12,18 +14,31 @@ except:
     pass
 
 
-greekSymbols = ["alpha", "beta", "chi", "delta", "Delta", "epsilon", "eta", "gamma", "Gamma", "iota", "kappa", "nu", "omega", "Omega", "omicron", "phi", "Phi", "pi", "Pi", "psi", "Psi", "rho", "sigma", "Sigma", "tau", "theta", "upsilon", "xi", "Xi"]
+greekSymbols = ["alpha", "beta", "chi", "delta", "Delta", "epsilon", "eta", \
+"gamma", "Gamma", "iota", "kappa", "nu", "omega", "Omega", "omicron", "phi", \
+"Phi", "pi", "Pi", "psi", "Psi", "rho", "sigma", "Sigma", "tau", "theta", \
+"upsilon", "xi", "Xi"]
 
-sympy_symbols_functions = ["acos()", "acosh()", "acot()", "acoth()", "asin()", "asinh()", "atan()", "atanh()", "cos()", "cosh()", "cot()", "coth()", "DiracDelta()", "E", "EulerGamma", "exp()", "factorial()", "fibonacci()", "gamma()", "GoldenRatio", "harmonic()", "hermite(n,x)", "I", "im()", "legendre(n,x)", "ln()", "ln(n,b)", "log()", "log(n,b)", "oo", "re()", "sin()", "sinh()", "sqrt()", "tan()", "tanh()", "zeta()"]
+sympy_symbols_functions = ["acos()", "acosh()", "acot()", "acoth()", "asin()", \
+"asinh()", "atan()", "atanh()", "cos()", "cosh()", "cot()", "coth()", \
+"DiracDelta()", "E", "EulerGamma", "exp()", "factorial()", "fibonacci()", \
+"gamma()", "GoldenRatio", "harmonic()", "hermite(n,x)", "I", "im()", \
+"legendre(n,x)", "ln()", "ln(n,b)", "log()", "log(n,b)", "oo", "re()", "sin()", \
+"sinh()", "sqrt()", "tan()", "tanh()", "zeta()"]
 
-historyIntegrandSamples = ["1/(alpha*x+beta)**3","1/sqrt(alpha*x+beta)","log(sigma*x)**2","sin(kappa*x)**5", "x**3/(alpha*x**2+beta)**2", "exp(omega*t**2)*t"]
+historyIntegrandSamples = ["1/(alpha*x+beta)**3", "1/sqrt(alpha*x+beta)", \
+"log(sigma*x)**2", "sin(kappa*x)**5", "x**3/(alpha*x**2+beta)**2", \
+"exp(omega*t**2)*t"]
 
-historyLimitSamples = ["pi/2","-pi/2","pi/3","-pi/3","pi/4","-pi/4","pi/6","-pi/6","-pi","-oo","0","1","-1"]
+historyLimitSamples = ["pi/2", "-pi/2", "pi/3", "-pi/3", "pi/4", "-pi/4", \
+"pi/6", "-pi/6", "-pi", "-oo","0","1","-1"]
 
 numerIntegralTypes = {'approx':0, 'infinities':1, 'smooth':2}
 integralType = {'indefinite':1, 'definite':2, 'numerical':3}
-simplifyType = {'none':0, 'expandterms':1, 'simplifyterms':2, 'expandall':3, 'simplifyall':4}
-outputType = {'simple':0, 'bidimensional':1, 'typesetting':2, 'latex':3, 'mathml':4, 'c':5, 'fortran':6}
+simplifyType = {'none':0, 'expandterms':1, 'simplifyterms':2, 'expandall':3, \
+                'simplifyall':4}
+outputType = {'simple':0, 'bidimensional':1, 'typesetting':2, 'latex':3, \
+              'mathml':4, 'c':5, 'fortran':6}
 integralErrorMessage = u'Error: integral not calculated'
 integralNumerErrorMessage = u'Error: numerical integral not calculated'
 
@@ -82,10 +97,7 @@ class IntegralWindow(QtGui.QMainWindow):
         self.nonCalculatedIntegral = u""
         self.resultIntegral = u""
         self.resultIntegralSimp = u""
-        self.resultOutput = u""
-        self.nonCalculatedIntegralOutput = u""
         self.timeIntegral = 0.0
-        self.configUpdateResult = False
         self.createMenuAndActions()
         self.createItems()
         self.showHideItems()
@@ -143,8 +155,12 @@ class IntegralWindow(QtGui.QMainWindow):
         self.limInf3Edit.setCompleter(self.limEditCompleter)
 
         self.font = QtGui.QFont()
-#        self.font.setFamily("Monospace")
-        self.font.setFamily("Dejavu Sans Mono")
+        self.font.setFamily("DejaVu Sans Mono")
+        if QtGui.QFontInfo(self.font).family() == "DejaVu Sans Mono":
+            self.dejavuSansMono = True
+        else:
+            self.font.setFamily("Monospace")
+            self.dejavuSansMono = False
         self.font.setPointSize(zoomFontSize[self.zoomLevel])
         self.resultEdit = QtGui.QTextBrowser()
         self.resultEdit.setReadOnly(False)
@@ -283,6 +299,7 @@ class IntegralWindow(QtGui.QMainWindow):
         helpAction = helpMenu.addAction(self.tr("&Help"))
         helpMenu.addSeparator()
         aboutAction = helpMenu.addAction(self.tr("&About"))
+        aboutQtAction = helpMenu.addAction(self.tr("About &Qt"))
 
         if self.isMaemo and (not self.isMaemo5):
             exitAction = QtGui.QAction(self.tr("E&xit"), self, shortcut="Ctrl+Q")
@@ -301,23 +318,24 @@ class IntegralWindow(QtGui.QMainWindow):
         self.connect(configAction, QtCore.SIGNAL("triggered()"), self.showConfigWindow)
         self.connect(helpAction, QtCore.SIGNAL("triggered()"), self.showHelpBox)
         self.connect(aboutAction, QtCore.SIGNAL("triggered()"), self.showAboutBox)
+        self.connect(aboutQtAction, QtCore.SIGNAL("triggered()"), QtGui.qApp.aboutQt)
 
     def showHelpBox(self):
         QtGui.QMessageBox.information(self, self.tr("Help on Integral"),
-            u'Mathematical operators : + - * / ** (power)\nExample of functions : sqrt, exp, log, sin, acos\n' +\
-            u'Examples of integrands : 1/(alpha*x+beta)**3,\n   sin(kappa*x)**5, exp(omega*t**2)*t\n'+\
+            u'Mathematical operators : + - * / ** (power)\nExamples of functions : sqrt, exp, log, sin, acos\n' +\
+            u'Examples of integrands : 1/(alpha*x+beta)**3, sin(kappa*x)**5, exp(omega*t**2)*t\n'+\
             u'Examples of variables : x, t, alpha, Omega\n'+u'Examples of limits : 0, -oo, pi/2, E, sqrt(1-y**2)\n'+\
             u'Look at the SymPy site: http://sympy.org/')
 
     def showAboutBox(self):
-        versionIntegral = '1.1.4'
+        versionIntegral = '1.1.5'
         siteIntegral = 'http://www.RobertoColistete.net/Integral\n'
         infoIntegral = self.tr("Calculation of integrals using ")
         infoPython = "Python v"+python_version()
         infoSymPy = "SymPy v"+__version__+" (http://sympy.org/)"
         QtGui.QMessageBox.information(self, self.tr("About Integral"),
             'Integral v'+versionIntegral+' - LGPLv3 (C) 2011 Roberto Colistete Jr.\n'+\
-            siteIntegral+infoIntegral+infoPython+" and\n"+infoSymPy+'\n\n* In loving memory of my wife Lorena *')
+            siteIntegral+infoIntegral+infoPython+" and "+infoSymPy+u'\n\n* In loving memory of my wife Lorena *')
 
     def showConfigWindow(self):
         if self.isMaemo5:
@@ -332,8 +350,6 @@ class IntegralWindow(QtGui.QMainWindow):
         self.configWin.setWindowTitle(self.tr("Integral (Settings)"))
         self.configWin.v_box = QtGui.QVBoxLayout()
 
-        self.configUpdateResult = False
-
         self.configWin.showIntegralCheckBox = QtGui.QCheckBox(self.tr("Show not calculated integral before result"))
         if self.showIntegral:
             self.configWin.showIntegralCheckBox.toggle()
@@ -454,32 +470,30 @@ class IntegralWindow(QtGui.QMainWindow):
 
     def zoomInMenu(self):
         if self.zoomLevel < (len(zoomFontSize)-1):
+            self.zoomLevel += 1
             if self.isMaemo5:
                 QMaemo5InformationBox.information(self, QtCore.QString("\nZoom in to font size "+str(zoomFontSize[self.zoomLevel])+"\n"), \
                                                   maemo5InformationBoxTime)
                 QApplication.processEvents()
-            self.zoomLevel += 1
             self.font.setPointSize(zoomFontSize[self.zoomLevel])
             self.resultEdit.setFont(self.font)
             # Setting the pretty printing of SymPy to use unicode characters and correct number of columns.
             init_printing(use_unicode=True, num_columns=self.zoomNumColumns[self.zoomLevel])
             self.updateResult(flagCalculate=False)
-            self.configUpdateResult = True
             self.saveSettings()          
 
     def zoomOutMenu(self):
         if self.zoomLevel > 0:
+            self.zoomLevel -= 1
             if self.isMaemo5:
                 QMaemo5InformationBox.information(self, QtCore.QString("\nZoom out to font size "+str(zoomFontSize[self.zoomLevel])+"\n"), \
                                                   maemo5InformationBoxTime)
                 QApplication.processEvents()
-            self.zoomLevel -= 1
             self.font.setPointSize(zoomFontSize[self.zoomLevel])
             self.resultEdit.setFont(self.font)
             # Setting the pretty printing of SymPy to use unicode characters and correct number of columns.
             init_printing(use_unicode=True, num_columns=self.zoomNumColumns[self.zoomLevel])
             self.updateResult(flagCalculate=False)
-            self.configUpdateResult = True
             self.saveSettings()          
 
     def toggleShowIntegral(self, status):
@@ -494,7 +508,6 @@ class IntegralWindow(QtGui.QMainWindow):
                 QMaemo5InformationBox.information(self, QtCore.QString("\nNot calculated integral is not visible\n"), maemo5InformationBoxTime)
                 QApplication.processEvents()
         self.updateResult(flagCalculate=False)
-        self.configUpdateResult = True
         self.saveSettings()
 
     def toggleShowTime(self, status):
@@ -509,12 +522,10 @@ class IntegralWindow(QtGui.QMainWindow):
                 QMaemo5InformationBox.information(self, QtCore.QString("\nCalculation time is not visible\n"), maemo5InformationBoxTime)
                 QApplication.processEvents()
         self.updateResult(flagCalculate=False)
-        self.configUpdateResult = True
         self.saveSettings()
 
     def changeSimplifyResult(self, option):
         self.simplifyResult = option
-        self.configUpdateResult = True
         self.saveSettings()
 
     def changeOutputResult(self, option):
@@ -526,7 +537,6 @@ class IntegralWindow(QtGui.QMainWindow):
                 QMaemo5InformationBox.information(self, QtCore.QString("\nIntegral result converted to bidimensional output\n"), maemo5InformationBoxTime)
             elif self.outputResult == outputType['typesetting']:
                 QMaemo5InformationBox.information(self, QtCore.QString("\nIntegral result converted to typesetting output\n"), maemo5InformationBoxTime)
-                QApplication.processEvents()
             elif self.outputResult == outputType['latex']:
                 QMaemo5InformationBox.information(self, QtCore.QString("\nIntegral result converted to LaTeX output\n"), maemo5InformationBoxTime)
             elif self.outputResult == outputType['mathml']:
@@ -537,7 +547,6 @@ class IntegralWindow(QtGui.QMainWindow):
                 QMaemo5InformationBox.information(self, QtCore.QString("\nIntegral result converted to Fortran output\n"), maemo5InformationBoxTime)
             QApplication.processEvents()
         self.updateResult(flagCalculate=False)
-        self.configUpdateResult = True
         self.saveSettings()
 
     def changeNumerIntegralType(self, option):
@@ -802,7 +811,7 @@ class IntegralWindow(QtGui.QMainWindow):
                 self.resultEdit.setTextColor(QtGui.QColor("darkGreen"))
                 self.resultEdit.append(u"Calculated after %f seconds :" % self.timeIntegral)
                 self.resultEdit.setTextColor(QtGui.QColor("black"))
-        if self.showIntegral:
+        if self.showIntegral and self.nonCalculatedIntegralOutput:
             self.resultEdit.setTextColor(QtGui.QColor("Blue"))
             self.resultEdit.append(u"%s\n=" % self.nonCalculatedIntegralOutput)
             self.resultEdit.setTextColor(QtGui.QColor("black"))
@@ -826,6 +835,20 @@ class IntegralWindow(QtGui.QMainWindow):
     def fixUnicodeText(self, str):
         if self.isMaemo:
             str = str.replace(u"⎽","_")
+        if self.isMaemo5 and (not self.dejavuSansMono):
+            str = str.replace(u"⎮",u'\u2223')
+            str = str.replace(u"⎜",u'\u2223')
+            str = str.replace(u"⎟",u'\u2223')
+            str = str.replace(u"⎢",u'\u2223')
+            str = str.replace(u"⎥",u'\u2223')
+            str = str.replace(u"⎛",u"⌈")
+            str = str.replace(u"⎡",u"⌈")
+            str = str.replace(u"⎝",u"⌊")
+            str = str.replace(u"⎣",u"⌊")
+            str = str.replace(u"⎞",u"⌉")
+            str = str.replace(u"⎤",u"⌉")
+            str = str.replace(u"⎠",u"⌋")
+            str = str.replace(u"⎦",u"⌋")
         str = str.replace(u"ℯ","e")
         str = str.replace(u"ⅈ","i")
         return str
